==> qtjambi-designer-5.15.4-sources.jar: io/qt/designer/QAbstractExtensionManager.java <==
package io.qt.designer;


/**
 * <p>Interface for extension managers in Qt Designer</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html">QAbstractExtensionManager</a></p>
 */
public interface QAbstractExtensionManager extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QAbstractExtensionManager}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QAbstractExtensionManager
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.QtPropertyMember(enabled=false)
        private java.util.Collection<Object> __rcExtension;
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QAbstractExtensionManager.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid){
                return extension_native_QObject_ptr_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), iid);
            }
            private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
            
            
            @Override
            @io.qt.QtUninvokable
            public void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
                registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
                if (factory != null) {
                    QtJambi_LibraryUtilities.internal.addReferenceCount(this, io.qt.designer.QAbstractExtensionManager.Impl.class, "__rcExtension", false, false, factory);
                }
            }
            private native static void registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
            
            
            @Override
            @io.qt.QtUninvokable
            public void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
                unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
                if (factory != null) {
                    QtJambi_LibraryUtilities.internal.removeFromCollectionReferenceCount(this, io.qt.designer.QAbstractExtensionManager.Impl.class, "__rcExtension", false, factory);
                }
            }
            private native static void unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QAbstractExtensionManager instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#extension">QAbstractExtensionManager::extension(QObject*,QString)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
        
        private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#registerExtensions">QAbstractExtensionManager::registerExtensions(QAbstractExtensionFactory*,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
        
        private native static void registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#unregisterExtensions">QAbstractExtensionManager::unregisterExtensions(QAbstractExtensionFactory*,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
        
        private native static void unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#extension">QAbstractExtensionManager::extension(QObject*,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#registerExtensions">QAbstractExtensionManager::registerExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#unregisterExtensions">QAbstractExtensionManager::unregisterExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
    
}

==> qtjambi-designer-5.15.10-sources.jar: io/qt/designer/QAbstractExtensionManager.java <==
package io.qt.designer;


/**
 * <p>Interface for extension managers in Qt Designer</p>
 * <p>Java wrapper for Qt's class <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html">QAbstractExtensionManager</a></p>
 */
public interface QAbstractExtensionManager extends io.qt.QtObjectInterface
{
    /**
     * <p>Implementor class for interface {@link io.qt.designer.QAbstractExtensionManager}</p>
     */
    public static abstract class Impl extends io.qt.QtObject
        implements io.qt.designer.QAbstractExtensionManager
    {
        static {
            QtJambi_LibraryUtilities.initialize();
        }
        
        @io.qt.QtPropertyMember(enabled=false)
        private java.util.Collection<Object> __rcExtension;
        
        @io.qt.NativeAccess
        private static final class ConcreteWrapper extends QAbstractExtensionManager.Impl {
            
            @io.qt.NativeAccess
            private ConcreteWrapper(QPrivateConstructor p) { super(p); }
            
            @Override
            @io.qt.QtUninvokable
            public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid){
                return extension_native_QObject_ptr_cref_QString_constfct(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(object), iid);
            }
            private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
            
            
            @Override
            @io.qt.QtUninvokable
            public void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
                registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
                if (factory != null) {
                    QtJambi_LibraryUtilities.internal.addReferenceCount(this, io.qt.designer.QAbstractExtensionManager.Impl.class, "__rcExtension", false, false, factory);
                }
            }
            private native static void registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
            
            
            @Override
            @io.qt.QtUninvokable
            public void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid){
                unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(factory), iid);
                if (factory != null) {
                    QtJambi_LibraryUtilities.internal.removeFromCollectionReferenceCount(this, io.qt.designer.QAbstractExtensionManager.Impl.class, "__rcExtension", false, factory);
                }
            }
            private native static void unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
            
        }
        
        
        public Impl(){
            super((QPrivateConstructor)null);
            initialize_native(this);
        }
        
        private native static void initialize_native(QAbstractExtensionManager instance);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#extension">QAbstractExtensionManager::extension(QObject*,QString)const</a></p>
         */
        @io.qt.QtUninvokable
        public abstract io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
        
        private native static io.qt.core.QObject extension_native_QObject_ptr_cref_QString_constfct(long __this__nativeId, long object, java.lang.String iid);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#registerExtensions">QAbstractExtensionManager::registerExtensions(QAbstractExtensionFactory*,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
        
        private native static void registerExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
        
        /**
         * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#unregisterExtensions">QAbstractExtensionManager::unregisterExtensions(QAbstractExtensionFactory*,QString)</a></p>
         */
        @io.qt.QtUninvokable
        public abstract void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
        
        private native static void unregisterExtensions_native_QAbstractExtensionFactory_ptr_cref_QString(long __this__nativeId, long factory, java.lang.String iid);
        
        /**
         * Constructor for internal use only.
         * @param p expected to be <code>null</code>.
         */
        @io.qt.NativeAccess
        protected Impl(QPrivateConstructor p) { super(p); } 
        
    }

    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#extension">QAbstractExtensionManager::extension(QObject*,QString)const</a></p>
     */
    @io.qt.QtUninvokable
    public io.qt.core.QObject extension(io.qt.core.QObject object, java.lang.String iid);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#registerExtensions">QAbstractExtensionManager::registerExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void registerExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qabstractextensionmanager.html#unregisterExtensions">QAbstractExtensionManager::unregisterExtensions(QAbstractExtensionFactory*,QString)</a></p>
     */
    @io.qt.QtUninvokable
    public void unregisterExtensions(io.qt.designer.QAbstractExtensionFactory factory, java.lang.String iid);
    
}
